==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/FileSpecificationType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FileSpecificationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FileSpecificationType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="volatileFile" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="description" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="resourceURL" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FileSpecificationType")
public class FileSpecificationType {

    @XmlAttribute(name = "volatileFile")
    protected Boolean volatileFile;
    @XmlAttribute(name = "description")
    protected String description;
    @XmlAttribute(name = "resourceURL")
    protected String resourceURL;

    /**
     * Gets the value of the volatileFile property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isVolatileFile() {
        if (volatileFile == null) {
            return false;
        } else {
            return volatileFile;
        }
    }

    /**
     * Sets the value of the volatileFile property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setVolatileFile(boolean value) {
        this.volatileFile = value;
    }

    public boolean isSetVolatileFile() {
        return (this.volatileFile!= null);
    }

    public void unsetVolatileFile() {
        this.volatileFile = null;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        if (description == null) {
            return "";
        } else {
            return description;
        }
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    public boolean isSetDescription() {
        return (this.description!= null);
    }

    /**
     * Gets the value of the resourceURL property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getResourceURL() {
        if (resourceURL == null) {
            return "";
        } else {
            return resourceURL;
        }
    }

    /**
     * Sets the value of the resourceURL property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setResourceURL(String value) {
        this.resourceURL = value;
    }

    public boolean isSetResourceURL() {
        return (this.resourceURL!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/FileSpecificationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to specify the location and additional parameters for running an application or opening a document.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for FileSpecificationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="FileSpecificationType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="volatileFile" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="description" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="resourceURL" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FileSpecificationType")
public class FileSpecificationType {

    @XmlAttribute(name = "volatileFile")
    protected Boolean volatileFile;
    @XmlAttribute(name = "description")
    protected String description;
    @XmlAttribute(name = "resourceURL")
    protected String resourceURL;

    /**
     * Gets the value of the volatileFile property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isVolatileFile() {
        if (volatileFile == null) {
            return false;
        } else {
            return volatileFile;
        }
    }

    /**
     * Sets the value of the volatileFile property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setVolatileFile(boolean value) {
        this.volatileFile = value;
    }

    public boolean isSetVolatileFile() {
        return (this.volatileFile!= null);
    }

    public void unsetVolatileFile() {
        this.volatileFile = null;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        if (description == null) {
            return "";
        } else {
            return description;
        }
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    public boolean isSetDescription() {
        return (this.description!= null);
    }

    /**
     * Gets the value of the resourceURL property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getResourceURL() {
        if (resourceURL == null) {
            return "";
        } else {
            return resourceURL;
        }
    }

    /**
     * Sets the value of the resourceURL property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setResourceURL(String value) {
        this.resourceURL = value;
    }

    public boolean isSetResourceURL() {
        return (this.resourceURL!= null);
    }

}
